#
# spec file for package wine
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_with hal

Name:           wine
BuildRequires:  alsa-devel bison capi4linux-devel cups-devel desktop-file-utils fdupes flex freeglut-devel freetype2-devel giflib-devel gnutls-devel libgphoto2-devel libgsm-devel libjpeg-devel liblcms-devel libpng-devel libtiff-devel libv4l-devel libxslt-devel ncurses-devel openal-soft-devel openldap2-devel prelink update-desktop-files valgrind-devel
%if %{with hal}
BuildRequires:  hal-devel
%endif
%if 0%{?suse_version} > 1130
BuildRequires:  sane-backends-devel
%else
BuildRequires:  sane-backends
%endif
%if 0%{?suse_version} > 1130
BuildRequires:  gstreamer-0_10-plugins-base-devel
%endif
License:        LGPLv2.1+
Group:          System/Emulators/PC
AutoReqProv:    on
Version:        1.3.26
Release:        1
Summary:        An MS Windows Emulator
Url:            http://www.winehq.com
# vanilla Wine release
Source0:        wine-%version.tar.bz2
Source1:        http://kegel.com/wine/winetricks
Source2:        http://kegel.com/wine/wisotool
Source3:        README.SuSE
Source4:        wine.desktop
Source5:        ubuntuwine.tar.bz2
# SUSE specific patches
# - currently none, but add them here
Patch0:         susepatches.patch
Recommends:     wine-gecko wine-mp3
%ifarch %ix86 x86_64
Requires:       wine-32bit = %version
%endif
# for winetricks:
Requires:       unzip cabextract
%ifarch x86_64
Requires:       libX11.so.6()(64bit) libXext.so.6()(64bit) libXcursor.so.1()(64bit) libXi.so.6()(64bit) libXxf86vm.so.1()(64bit) libXrender.so.1()(64bit) libXrandr.so.2()(64bit) libXinerama.so.1()(64bit) libXcomposite.so.1()(64bit) libGL.so.1()(64bit) libGLU.so.1()(64bit) libxslt.so.1()(64bit) libncurses.so.6()(64bit) libfreetype.so.6()(64bit) libfontconfig.so.1()(64bit) libcups.so.2()(64bit)
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
An MS Windows emulator, consisting of both runtime and source
compatibility functions. You can run your MS executables with it and
write your Windows programs under Linux and link against the WINE
libraries.

It is not necessary to have a Windows installation to run WINE.

Refer to /usr/share/doc/packages/wine/README.SuSE. There is more
documentation available in that directory. Read 'man wine' for further
information.

You can invoke wine by entering 'wine program.exe'. Configure it by
running 'winecfg'.

%ifarch %ix86

%package 32bit
Summary:        The 32bit runtime system of Wine
License:        LGPLv2.1+
Group:          System/Emulators/PC
# requires either 32bit or 64bit wine
Requires:       wine = %version
# lib dependencies that are dynamically loaded
Requires:       libXcursor.so.1 libXi.so.6 libXxf86vm.so.1 libXrender.so.1 libXrandr.so.2 libXinerama.so.1 libXcomposite.so.1 libxslt.so.1 libncurses.so.6 libfreetype.so.6 libcrypto.so.1.0.0 libssl.so.1.0.0 libfontconfig.so.1 libcups.so.2 libgnutls.so.26 libpng14.so.14

%description 32bit
This package contains the 32bit runtime environmnent (libraries, DLLs, EXEs) of Wine.
It is required to run Win32 binaries. It requires either the 32bit or 64bit
"wine" environment to work.
%endif

%package devel
License:        LGPLv2.1+
Summary:        files for wine development
Group:          System/Emulators/PC

%description devel
This RPM contains the header files and development tools for the WINE
libraries.



%prep
%setup -q
%patch0 -p1
#
cp %{S:3} .
#

%build
cat VERSION
%ifarch %ix86
# e.g. Steam hates it.
export RPM_OPT_FLAGS=`echo $RPM_OPT_FLAGS|sed -e 's/-fomit-frame-pointer//'`
%endif
# keep just for susepatches with configure changes
autoconf
autoheader -I include
%configure \
	--with-x \
%ifarch x86_64
        --enable-win64 \
%endif
	--verbose

cat config.log
grep "have_x=yes" config.log || exit 1
make %{?jobs:-j%jobs} depend
make %{?jobs:-j%jobs} all

%install
make install DESTDIR=$RPM_BUILD_ROOT
# install desktop file
install -d $RPM_BUILD_ROOT/usr/share/applications/
%suse_update_desktop_file %{SOURCE4} Emulator

install -m 0644 %SOURCE4 $RPM_BUILD_ROOT/usr/share/applications/
install -m 0755 %SOURCE1 $RPM_BUILD_ROOT/usr/bin/
install -m 0755 %SOURCE2 $RPM_BUILD_ROOT/usr/bin/
mv $RPM_BUILD_ROOT/%{_mandir}/de.UTF-8 $RPM_BUILD_ROOT/%{_mandir}/de
mv $RPM_BUILD_ROOT/%{_mandir}/fr.UTF-8 $RPM_BUILD_ROOT/%{_mandir}/fr
mv $RPM_BUILD_ROOT/%{_mandir}/pl.UTF-8 $RPM_BUILD_ROOT/%{_mandir}/pl
tar xjf %{SOURCE5}
# Copied from Ubuntu Wine out of debian.diff
# https://launchpad.net/~ubuntu-wine/+archive/ppa/+packages
# taken on 1.2rc2 time.
cd ubuntuwine
        install -d $RPM_BUILD_ROOT/etc/xdg/menus/applications-merged
        install -c -m 644 wine.menu $RPM_BUILD_ROOT/etc/xdg/menus/applications-merged

        # Install application-specific desktop files
        install -d $RPM_BUILD_ROOT/usr/share/applications
        install -c -m 644 *.desktop $RPM_BUILD_ROOT/usr/share/applications/

        install -d $RPM_BUILD_ROOT/usr/share/desktop-directories/
        install -c -m 644 *.directory $RPM_BUILD_ROOT/usr/share/desktop-directories/

        # Install icons
        install -d $RPM_BUILD_ROOT/usr/share/icons/hicolor/scalable/apps/
        install -c -m 644 *.svg $RPM_BUILD_ROOT/usr/share/icons/hicolor/scalable/apps/
cd ..

%fdupes -s $RPM_BUILD_ROOT

%clean
rm -rf $RPM_BUILD_ROOT

%ifarch %ix86

%post 32bit -p /sbin/ldconfig

%postun 32bit -p /sbin/ldconfig
%else

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig
%endif

%files
%defattr(-,root,root)
%doc ANNOUNCE AUTHORS LICENSE LICENSE.OLD README* 
/usr/bin/function_grep.pl
/usr/bin/msiexec
/usr/bin/notepad
/usr/bin/regedit
/usr/bin/regsvr32
/usr/bin/wineboot
/usr/bin/winecfg
/usr/bin/wineconsole
/usr/bin/winedbg
/usr/bin/winefile
/usr/bin/winemine
/usr/bin/winepath
/usr/bin/wineserver
/usr/bin/winetricks
/usr/bin/wisotool
/usr/share/wine
/usr/share/applications/wine.desktop
%doc %{_mandir}/man1/wine.1*
%doc %{_mandir}/man1/winedbg.1*
%doc %{_mandir}/man1/wineserver.1*
%doc %dir %doc %{_mandir}/pl
%doc %dir %doc %{_mandir}/pl/man1
%doc %{_mandir}/*/man1/wine.1*
%doc %{_mandir}/*/man1/wineserver.1*
%doc %{_mandir}/man1/msiexec.1.*
%doc %{_mandir}/man1/notepad.1.*
%doc %{_mandir}/man1/regedit.1.*
%doc %{_mandir}/man1/regsvr32.1.*
%doc %{_mandir}/man1/wineboot.1.*
%doc %{_mandir}/man1/winebuild.1.*
%doc %{_mandir}/man1/winecfg.1.*
%doc %{_mandir}/man1/wineconsole.1.*
%doc %{_mandir}/man1/winecpp.1.*
%doc %{_mandir}/man1/winefile.1.*
%doc %{_mandir}/man1/winemine.1.*
%doc %{_mandir}/man1/winepath.1.*
%dir /etc/xdg/menus/
%dir /etc/xdg/menus/applications-merged
%config /etc/xdg/menus/applications-merged/*.menu
/usr/share/applications/*.desktop
%dir /usr/share/desktop-directories/
/usr/share/desktop-directories/*.directory 
%dir /usr/share/icons/hicolor
%dir /usr/share/icons/hicolor/scalable
%dir /usr/share/icons/hicolor/scalable/apps
/usr/share/icons/hicolor/scalable/apps/*.svg

%if 0%{?suse_version} > 1120
%ifarch %ix86

%files 32bit
%defattr(-,root,root)
%endif
%endif
%ifarch %ix86
/usr/bin/wine
/usr/bin/wine-preloader
%endif
%ifarch ppc
/usr/bin/wine
%endif
%ifarch x86_64
/usr/bin/wine64
/usr/bin/wine64-preloader
%endif
%{_libdir}/wine/*.so
%{_libdir}/lib*.so.*
%dir %{_libdir}/wine
%dir %{_libdir}/wine/fakedlls
%{_libdir}/wine/fakedlls/*

%files devel
%defattr(-,root,root)
%{_includedir}/wine
/usr/bin/widl
/usr/bin/winebuild
/usr/bin/winecpp
/usr/bin/winedump
/usr/bin/wineg++
/usr/bin/winegcc
/usr/bin/winemaker
/usr/bin/wmc
/usr/bin/wrc
%{_libdir}/wine/*.def
%{_libdir}/wine/*.a
%{_libdir}/lib*.so
%doc %{_mandir}/man1/winemaker.1*
%doc %{_mandir}/*/man1/winemaker.1*
%doc %{_mandir}/man1/widl.1*
%doc %{_mandir}/man1/winedump.1*
%doc %{_mandir}/man1/wineg++.1*
%doc %{_mandir}/man1/winegcc.1*
%doc %{_mandir}/man1/wmc.1*
%doc %{_mandir}/man1/wrc.1*

# /usr/share/aclocal/wine.m4

%changelog
